# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# With UsrMove (F-17, RHEL-7 onwards), we want the library installed to %%{_libdir} rather than /%%{_lib}
%global UsrMove %([ 0%{?fedora} -gt 16 -o 0%{?rhel} -gt 6 ] && echo 1 || echo 0)

Summary:	A C library for portable packet creation and injection
Name:		libnet
Version:	1.1.6
Release:	20.0.cf.%{__distinit}%{__distvers}
License:	BSD
URL:		http://sourceforge.net/projects/libnet-dev/
Source0:	http://downloads.sf.net/libnet-dev/libnet-%{version}.tar.gz
Patch0:		libnet-1.1.6-sample-include.patch
BuildRequires:	coreutils
BuildRequires:	gcc
BuildRequires:	make
%if %{UsrMove}
Conflicts:	filesystem < 3
%else
BuildRequires:	symlinks
%endif

%description
Libnet is an API to help with the construction and handling of network
packets. It provides a portable framework for low-level network packet
writing and handling (use libnet in conjunction with libpcap and you can
write some really cool stuff). Libnet includes packet creation at the IP
layer and at the link layer as well as a host of supplementary and
complementary functionality.

%package devel
Summary:	Development files for the libnet library
Requires:	%{name}%{?_isa} = %{version}-%{release}

%description devel
The libnet-devel package includes header files and libraries necessary
for developing programs which use the libnet library. Libnet is very handy
with which to write network tools and network test code. See the manpage
and sample test code for more detailed information.

%prep
%setup -q

# Fix up header file inclusion in sample code
%patch0

%build
%if %{UsrMove}
%configure
%else
%configure --libdir=/%{_lib}
%endif
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} INSTALL="install -p" install

%if ! %{UsrMove}
# Move libnet.so to %%{_libdir}
mkdir -p %{buildroot}%{_libdir}
rm %{buildroot}/%{_lib}/libnet.so
ln -s %{buildroot}/%{_lib}/libnet.so.*.*.* %{buildroot}%{_libdir}/libnet.so
symlinks -cs %{buildroot}%{_libdir}
%endif

# Discard stuff we don't want packaged
%if %{UsrMove}
rm %{buildroot}%{_libdir}/libnet.{a,la}
%else
rm %{buildroot}/%{_lib}/libnet.{a,la}
%endif
make -C sample clean
rm -rf sample/{win32,Makefile.{am,in}}
rm -f doc/html/Makefile*

%if (0%{?rhel} && 0%{?rhel} <= 7) || (0%{?fedora} && 0%{?fedora} <= 27)
# ldconfig replaced by RPM File Triggers from Fedora 28
%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig
%endif

%files
%if 0%{?_licensedir:1}
%license doc/COPYING
%else
%doc doc/COPYING
%endif
%doc README doc/CHANGELOG doc/CONTRIB
%if %{UsrMove}
%{_libdir}/libnet.so.*
%else
/%{_lib}/libnet.so.*
%endif

%files devel
%doc doc/DESIGN_NOTES doc/MIGRATION doc/PACKET_BUILDING
%doc doc/RAWSOCKET_NON_SEQUITUR doc/TODO doc/html/ sample/
%{_bindir}/libnet-config
%{_libdir}/libnet.so
%{_includedir}/libnet.h
%{_includedir}/libnet/
%{_mandir}/man3/libnet-functions.h.3*
%{_mandir}/man3/libnet-macros.h.3*
%{_mandir}/man3/libnet.h.3*

%changelog
* Tue Jul 28 2020 Paul Howarth <paul@city-fan.org> - 1.1.6-20.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Fri Jan 31 2020 Paul Howarth <paul@city-fan.org> - 1.1.6-19.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Thu Jul 25 2019 Paul Howarth <paul@city-fan.org> - 1.1.6-18.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Tue Feb  5 2019 Paul Howarth <paul@city-fan.org> - 1.1.6-17.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Mon Jul 16 2018 Paul Howarth <paul@city-fan.org> - 1.1.6-16.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Mon Feb 19 2018 Paul Howarth <paul@city-fan.org> - 1.1.6-15.0.cf
- ldconfig replaced by RPM File Triggers from Fedora 28
- Specify all explicitly used build requirements

* Mon Aug 14 2017 Paul Howarth <paul@city-fan.org> - 1.1.6-14.0.cf
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Sun Feb 12 2017 Paul Howarth <paul@city-fan.org> - 1.1.6-12.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Fri Feb  5 2016 Paul Howarth <paul@city-fan.org> - 1.1.6-11.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sun Jun 21 2015 Paul Howarth <paul@city-fan.org> - 1.1.6-10.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue Aug 19 2014 Paul Howarth <paul@city-fan.org> - 1.1.6-9.0.cf
- Use %%license where possible

* Wed Jun 11 2014 Paul Howarth <paul@city-fan.org> - 1.1.6-8.0.cf
- Drop %%defattr, redundant sice rpm 4.4

* Sat Dec 21 2013 Paul Howarth <paul@city-fan.org> - 1.1.6-7.0.cf
- Tighten run-time dependencies between sub-packages using %%{?_isa}

* Sun Aug  4 2013 Paul Howarth <paul@city-fan.org> - 1.1.6-6.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sun Feb 24 2013 Paul Howarth <paul@city-fan.org> - 1.1.6-5.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Tue Jul 24 2012 Paul Howarth <paul@city-fan.org> - 1.1.6-4.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Mon Apr  2 2012 Paul Howarth <paul@city-fan.org> - 1.1.6-3.0.cf
- Add filesystem guard for UsrMove

* Sun Apr  1 2012 Paul Howarth <paul@city-fan.org> - 1.1.6-1.0.cf
- Update to 1.1.6 (see CHANGELOG for details)
- For F-17/RHEL-7 onwards, install to %%{_libdir} rather than /%%{_lib}
- Fix up sample header file in %%prep rather than %%install
- Upstream no longer ships doc/BUGS

* Sat Aug  6 2011 Paul Howarth <paul@city-fan.org> - 1.1.5-3.0.cf
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Fri Feb 11 2011 Paul Howarth <paul@city-fan.org> - 1.1.5-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Fri Dec 31 2010 Paul Howarth <paul@city-fan.org> - 1.1.5-1.0.cf
- Updated to 1.1.5 (see CHANGELOG for details)

* Fri May 14 2010 Paul Howarth <paul@city-fan.org> - 1.1.4-5.0.cf
- Fix dist tag for RHEL-6 Beta

* Wed Feb 24 2010 Paul Howarth <paul@city-fan.org> - 1.1.4-4.0.cf
- Dist tag for Rawhide no longer needs special-casing

* Thu Aug 27 2009 Paul Howarth <paul@city-fan.org> - 1.1.4-3.0.cf
- Updated to 1.1.4
- Add dist tags
- Clean out old cruft
- Upstream development now at http://sourceforge.net/projects/libnet-dev/
- Split off -devel subpackage
- Install into /%%{_lib} for benefit of syslog type apps (#518150)
- Enable parallel build
- Maintain timestamps of untouched upstream files
- Add scriptlets to run ldconfig since the library is now shared, not static
- Add buildreq symlinks
- Fix header file location in sample code

* Mon Sep 20 2004 Paul Howarth <paul@city-fan.org> - 1.1.2.1
- Rewritten for 1.1.2.1

* Mon Dec 16 2002 Dag Wieers <dag@wieers.com> - 1.0.2
- Updated to 1.0.2a (1.1.0 does not work with 1.1.0)

* Thu Aug 02 2001 Dag Wieers <dag@wieers.com> - 1.0.1
- Initial package
